@@ -20,6 +20,7 @@ from .base import (
 from .distance import (
     PNormDistance,
     AdaptivePNormDistance,
+    InfoWeightedPNormDistance,
     AggregatedDistance,
     AdaptiveAggregatedDistance,
     ZScoreDistance,
@@ -31,13 +32,21 @@ from .distance import (
 )
 from .scale import (
     median_absolute_deviation,
+    mad,
     mean_absolute_deviation,
     standard_deviation,
+    std,
     bias,
     root_mean_square_deviation,
+    rmsd,
+    std_or_rmsd,
     median_absolute_deviation_to_observation,
+    mado,
+    mad_or_cmad,
+    pcmad,
     mean_absolute_deviation_to_observation,
     combined_median_absolute_deviation,
+    cmad,
     combined_mean_absolute_deviation,
     standard_deviation_to_observation,
     span,
