@@ -7,7 +7,7 @@ import cloudpickle as pickle
 import copy
 import logging
 from redis import StrictRedis
-from typing import Callable, List, Tuple
+from typing import Callable, Dict, List, Tuple
 from jabbar import jabbar
 
 from ...util import (
@@ -16,8 +16,9 @@ from ...util import (
 from ...distance import Distance
 from ...epsilon import Epsilon
 from ...acceptor import Acceptor
-from ...sampler import Sampler, Sample
+from ...sampler import Sampler
 from ...weighted_statistics import effective_sample_size
+from ...population import Sample
 from .cmd import (
     SSA, N_EVAL, N_ACC, N_REQ, N_FAIL, N_LOOKAHEAD_EVAL, ALL_ACCEPTED,
     N_WORKER, QUEUE, MSG, START, MODE, DYNAMIC, SLEEP_TIME, BATCH_SIZE,
@@ -48,11 +49,13 @@ class RedisSamplerBase(Sampler):
         logging module.
     """
 
-    def __init__(self,
-                 host: str = "localhost",
-                 port: int = 6379,
-                 password: str = None,
-                 log_file: str = None):
+    def __init__(
+        self,
+        host: str = "localhost",
+        port: int = 6379,
+        password: str = None,
+        log_file: str = None,
+    ):
         super().__init__()
         logger.debug(
             f"Redis sampler: host={host} port={port}")
@@ -175,16 +178,18 @@ class RedisEvalParallelSampler(RedisSamplerBase):
         logging module.
     """
 
-    def __init__(self,
-                 host: str = "localhost",
-                 port: int = 6379,
-                 password: str = None,
-                 batch_size: int = 1,
-                 look_ahead: bool = False,
-                 look_ahead_delay_evaluation: bool = True,
-                 max_n_eval_look_ahead_factor: float = 10.,
-                 wait_for_all_samples: bool = False,
-                 log_file: str = None):
+    def __init__(
+        self,
+        host: str = "localhost",
+        port: int = 6379,
+        password: str = None,
+        batch_size: int = 1,
+        look_ahead: bool = False,
+        look_ahead_delay_evaluation: bool = True,
+        max_n_eval_look_ahead_factor: float = 10.,
+        wait_for_all_samples: bool = False,
+        log_file: str = None,
+    ):
         super().__init__(
             host=host, port=port, password=password, log_file=log_file)
         self.batch_size: int = batch_size
@@ -195,7 +200,7 @@ class RedisEvalParallelSampler(RedisSamplerBase):
 
     def sample_until_n_accepted(
             self, n, simulate_one, t, *,
-            max_eval=np.inf, all_accepted=False, ana_vars=None):
+            max_eval=np.inf, all_accepted=False, ana_vars=None) -> Sample:
         # get the analysis id
         ana_id = self.analysis_id
 
@@ -295,10 +300,17 @@ class RedisEvalParallelSampler(RedisSamplerBase):
 
         # remove all time-specific variables if no more active workers,
         #  also for previous generations
-        for _t in range(-1, t+1):
-            n_worker_b = self.redis.get(idfy(N_WORKER, ana_id, _t))
-            if n_worker_b is not None and int(n_worker_b.decode()) == 0:
-                self.clear_generation_t(t=_t)
+        if self.wait_for_all_samples:
+            self.clear_generation_t(t=t)
+        else:
+            for _t in range(-1, t+1):
+                n_worker_b = self.redis.get(idfy(N_WORKER, ana_id, _t))
+                if n_worker_b is not None and int(n_worker_b.decode()) == 0:
+                    # TODO For fast-running models, communication does not
+                    #  always work.
+                    # Until that is fixed, simply do not clear up.
+                    # self.clear_generation_t(t=_t)
+                    pass
 
         # create a single sample result, with start time correction
         sample = self.create_sample(id_results, n)
@@ -309,14 +321,19 @@ class RedisEvalParallelSampler(RedisSamplerBase):
             n_lookahead=n_lookahead_eval)
         self.logger.write()
 
-        # weight samples correctly
+        # weight sub-populations suitably
         sample = self_normalize_within_subpopulations(sample, n)
 
         return sample
 
     def start_generation_t(
-            self, n: int, t: int, simulate_one: Callable, all_accepted: bool,
-            is_look_ahead: bool, max_n_eval_look_ahead: float = np.inf,
+        self,
+        n: int,
+        t: int,
+        simulate_one: Callable,
+        all_accepted: bool,
+        is_look_ahead: bool,
+        max_n_eval_look_ahead: float = np.inf,
     ) -> None:
         """Start generation `t`."""
         ana_id = self.analysis_id
@@ -385,8 +402,13 @@ class RedisEvalParallelSampler(RedisSamplerBase):
          .execute())
 
     def maybe_start_next_generation(
-            self, t: int, n: int, id_results: List, all_accepted: bool,
-            ana_vars: AnalysisVars) -> None:
+        self,
+        t: int,
+        n: int,
+        id_results: List,
+        all_accepted: bool,
+        ana_vars: AnalysisVars,
+    ) -> None:
         """Start the next generation already, if that looks reasonable.
 
         Parameters
@@ -411,6 +433,12 @@ class RedisEvalParallelSampler(RedisSamplerBase):
         # copy as we modify the particles
         sample = copy.deepcopy(sample)
 
+        # weight sub-populations suitably
+        sample = self_normalize_within_subpopulations(sample, n)
+
+        # normalize accepted population weight to 1
+        sample.normalize_weights()
+
         # extract population
         population = sample.get_accepted_population()
 
@@ -445,7 +473,7 @@ class RedisEvalParallelSampler(RedisSamplerBase):
 
         # create a preliminary simulate_one function
         simulate_one_prel = create_preliminary_simulate_one(
-            t=t+1, population=population,
+            t=t + 1, population=population,
             delay_evaluation=self.look_ahead_delay_evaluation,
             ana_vars=ana_vars)
 
@@ -463,7 +491,7 @@ class RedisEvalParallelSampler(RedisSamplerBase):
         # head-start the next generation
         #  all_accepted is most certainly False for t>0
         self.start_generation_t(
-            n=n, t=t+1, simulate_one=simulate_one_prel,
+            n=n, t=t + 1, simulate_one=simulate_one_prel,
             all_accepted=False, is_look_ahead=True,
             max_n_eval_look_ahead=max_n_eval_look_ahead)
 
@@ -488,10 +516,12 @@ class RedisEvalParallelSampler(RedisSamplerBase):
         return sample
 
     def check_analysis_variables(
-            self,
-            distance_function: Distance,
-            eps: Epsilon,
-            acceptor: Acceptor) -> None:
+        self,
+        distance_function: Distance,
+        eps: Epsilon,
+        acceptor: Acceptor,
+    ) -> None:
+        """"Check analysis variables appropriateness for sampling."""
         if self.look_ahead_delay_evaluation:
             # nothing to be done
             return
@@ -512,7 +542,7 @@ class RedisEvalParallelSampler(RedisSamplerBase):
 
 
 def create_preliminary_simulate_one(
-        t, population, delay_evaluation: bool, ana_vars: AnalysisVars,
+    t, population, delay_evaluation: bool, ana_vars: AnalysisVars,
 ) -> Callable:
     """Create a preliminary simulate_one function for generation `t`.
 
@@ -555,8 +585,10 @@ def create_preliminary_simulate_one(
     )
 
 
-def post_check_acceptance(sample_with_id, ana_id, t, redis, ana_vars,
-                          logger: RedisSamplerLogger) -> Tuple:
+def post_check_acceptance(
+    sample_with_id, ana_id, t, redis, ana_vars,
+    logger: RedisSamplerLogger,
+) -> Tuple:
     """Check whether the sample is really acceptable.
 
     This is where evaluation of preliminary samples happens, using the analysis
@@ -571,11 +603,11 @@ def post_check_acceptance(sample_with_id, ana_id, t, redis, ana_vars,
         kept.
     """
     # 0 is relative start time, 1 is the actual sample
-    sample = sample_with_id[1]
+    sample: Sample = sample_with_id[1]
 
     # check whether there are preliminary particles
-    if not any(particle.preliminary for particle in sample.particles):
-        n_accepted = sum(particle.accepted for particle in sample.particles)
+    if not any(particle.preliminary for particle in sample.all_particles):
+        n_accepted = len(sample.accepted_particles)
         if n_accepted != 1:
             # this should never happen
             raise AssertionError(
@@ -592,30 +624,37 @@ def post_check_acceptance(sample_with_id, ana_id, t, redis, ana_vars,
         return sample_with_id, True
 
     # in preliminary mode, there should only be one particle per sample
-    if len(sample.particles) != 1:
+    if len(sample.all_particles) != 1:
         # this should never happen
         raise AssertionError(
             "Expected number of particles in sample: 1. "
-            f"Got: {len(sample.particles)}")
+            f"Got: {len(sample.all_particles)}")
 
     # from here on, we may assume that all particles (#=1) are yet to be judged
     logger.n_preliminary += 1
 
     # iterate over the 1 particle
-    for i_particle, particle in enumerate(sample.particles):
-        sample.particles[i_particle] = \
+    for particle in sample.all_particles:
+        particle = \
             evaluate_preliminary_particle(particle, t, ana_vars)
 
         # react to acceptance
-        if sample.particles[i_particle].accepted:
+        if particle.accepted:
+            sample.accepted_particles = [particle]
+            sample.rejected_particles = []
             # increase redis shared counter
             redis.incr(idfy(N_ACC, ana_id, t), 1)
             # increase general and lookahead counter
             logger.n_accepted += 1
             logger.n_lookahead_accepted += 1
+        else:
+            sample.accepted_particles = []
+            if sample.record_rejected:
+                sample.rejected_particles = [particle]
+            else:
+                sample.rejected_particles = []
 
-    return (sample_with_id,
-            any(particle.accepted for particle in sample.particles))
+    return sample_with_id, len(sample.accepted_particles) > 0
 
 
 def self_normalize_within_subpopulations(sample: Sample, n: int) -> Sample:
@@ -630,27 +669,26 @@ def self_normalize_within_subpopulations(sample: Sample, n: int) -> Sample:
     -------
     sample: The same, weight-adjusted sample.
     """
-    prop_ids = {particle.proposal_id for particle in sample.particles}
+    prop_ids = {particle.proposal_id for particle in sample.accepted_particles}
 
     if len(prop_ids) == 1:
         # Nothing to be done, as we only have one proposal, and normalization
         #  is applied later when the population is created
         return sample
 
-    accepted_particles = sample.accepted_particles
-    if len(accepted_particles) != n:
+    if len(sample.accepted_particles) != n:
         # this should not happen
         raise AssertionError("Unexpected number of acceptances")
 
     # get particles per proposal
     particles_per_prop = {
-        prop_id: [particle for particle in accepted_particles
+        prop_id: [particle for particle in sample.accepted_particles
                   if particle.proposal_id == prop_id]
         for prop_id in prop_ids}
 
-    # normalize weights by ESS_l / sum_l[w_l] for proposal id l
-    # this is s.t. sum_i w_{l,i} \propto ESS_l
-    normalizations = {}
+    # normalize weights by $ESS_l / sum_{i<=N_l} w^l_i$ for proposal id l
+    # this is s.t. $sum_{i<=N_l} w^l_i \propto ESS_l$
+    normalizations: Dict[int, float] = {}
     for prop_id, particles_for_prop in particles_per_prop.items():
         weights = np.array(
             [particle.weight for particle in particles_for_prop])
@@ -658,16 +696,23 @@ def self_normalize_within_subpopulations(sample: Sample, n: int) -> Sample:
         total_weight = weights.sum()
         normalizations[prop_id] = ess / total_weight
 
-    # normalize every particle (this includes rejected ones, which should not
-    #  be necessary, but does not hurt)
-    for particle in sample.particles:
-        particle.weight *= normalizations[particle.proposal_id]
+    # normalize all particles
+    for particle in sample.all_particles:
+        if particle.proposal_id in normalizations:
+            particle.weight *= normalizations[particle.proposal_id]
+        else:
+            # set weight of particles from populations None of which was
+            #  accepted to 0 (until we start caring about those for real)
+            particle.weight = 0.
 
     return sample
 
 
 def _log_active_set(
-    redis: StrictRedis, ana_id: str, t: int, id_results: List[Tuple],
+    redis: StrictRedis,
+    ana_id: str,
+    t: int,
+    id_results: List[Tuple],
     batch_size: int,
 ) -> None:
     """Log the status of active simulations after the first n acceptances."""
