@@ -1,4 +1,6 @@
 import json
+import numpy as np
+import copy
 
 
 def save_dict_to_json(dct: dict, file_: str):
@@ -12,6 +14,11 @@ def save_dict_to_json(dct: dict, file_: str):
     file_:
         Name of the file to write to.
     """
+    dct = copy.deepcopy(dct)
+    for key, val in dct.items():
+        # cannot handle ndarrays
+        if isinstance(val, np.ndarray):
+            dct[key] = list(val)
     with open(file_, 'w') as f:
         json.dump(dct, f)
 
@@ -36,5 +43,5 @@ def load_dict_from_json(file_: str, key_type: type = int):
         _dct = json.load(f)
     dct = {}
     for key, val in _dct.items():
-        dct[int(key)] = val
+        dct[key_type(key)] = val
     return dct
