@@ -52,22 +52,48 @@ def weighted_median(points, weights):
 
 
 @weight_checked
-def weighted_mean(points, weights):
+def weighted_mean(points: np.ndarray, weights: np.ndarray):
+    """Compute the weighted mean.
+
+    Parameters
+    ----------
+    points: Parameter samples, shape (n_sample,) or (n_sample, n_par).
+    weights: Weights, shape (n_sample,) or (n_sample, 1).
+
+    Returns
+    -------
+    mean: The mean, shape () or (n_par,).
     """
-    Compute the weighted mean.
-    """
-    return (points * weights).sum()
+    return (points * weights).sum(axis=0)
 
 
-@weight_checked
-def weighted_std(points, weights):
-    """
-    Compute the weighted standard deviation from the
-    weighted mean.
+def weighted_var(points, weights):
+    """Compute the weighted variance.
+
+    See `weighted_mean` for docs.
     """
     mean = weighted_mean(points, weights)
-    std = np.sqrt(((points - mean)**2 * weights).sum())
-    return std
+    return ((points - mean)**2 * weights).sum(axis=0)
+
+
+def weighted_std(points, weights):
+    """Compute the weighted standard deviation.
+
+    See `weighted_mean` for docs.
+    """
+    return np.sqrt(weighted_var(points, weights))
+
+
+def weighted_mse(points, weights, refval):
+    """Compute the weighted mean square error."""
+    var = weighted_var(points, weights)
+    bias = weighted_mean(points, weights) - refval
+    return var + bias**2
+
+
+def weighted_rmse(points, weights, refval):
+    """Compute the weighted root mean square error."""
+    return np.sqrt(weighted_mse(points, weights, refval))
 
 
 def effective_sample_size(weights):
@@ -83,7 +109,7 @@ def effective_sample_size(weights):
     ----------
     weights: Importance sampling weights.
     """
-    weights = np.array(weights)
+    weights = np.asarray(weights)
     n_eff = np.sum(weights)**2 / np.sum(weights**2)
     return n_eff
 
@@ -107,7 +133,7 @@ def resample(points, weights, n):
         A total of `n` points sampled from `points` with putting back
         according to `weights`.
     """
-    weights = np.array(weights)
+    weights = np.asarray(weights)
     weights /= np.sum(weights)
     resampled = np.random.choice(points, size=n, p=weights)
     return resampled
@@ -139,7 +165,7 @@ def resample_deterministic(points, weights, n, enforce_n=False):
         A total of (roughly) `n` points resampled from `points`
         deterministically using a rational representation of the `weights`.
     """
-    weights = np.array(weights)
+    weights = np.asarray(weights)
     numbers_f = weights * (n / np.sum(weights))
 
     numbers = np.round(numbers_f)
