@@ -1,13 +1,14 @@
 """Execute petab test suite."""
 
 import petabtests
-import pyabc
-
 import os
+import sys
 import pytest
 from _pytest.outcomes import Skipped
 import logging
 
+import pyabc
+
 try:
     import petab
     import pyabc.petab
@@ -44,7 +45,7 @@ def execute_case(case):
         _execute_case(case)
     except Exception as e:
         if isinstance(e, NotImplementedError) \
-                or "Timepoint-specific parameter overrides" in str(e):
+                or "timepoint specific" in str(e):
             logger.info(
                 f"Case {case} expectedly failed. Required functionality is "
                 f"not implemented: {e}")
@@ -80,9 +81,12 @@ def _execute_case(case):
     petab_problem = petab.Problem.from_yaml(yaml_file)
 
     # compile amici
+    if output_folder not in sys.path:
+        sys.path.insert(0, output_folder)
     amici_model = amici.petab_import.import_petab_problem(
         petab_problem=petab_problem,
-        model_output_dir=output_folder)
+        model_output_dir=output_folder,
+    )
     solver = amici_model.getSolver()
 
     # import to pyabc
@@ -91,7 +95,7 @@ def _execute_case(case):
     model = importer.create_model(return_rdatas=True)
 
     # simulate
-    problem_parameters = petab_problem.x_nominal_free_scaled
+    problem_parameters = importer.get_nominal_parameters()
     ret = model(problem_parameters)
 
     llh = ret['llh']
